@@ -14,11 +14,11 @@ class Settings(DefaultsDict):
     def __init__(
         self,
         settings_file_path: str,
-        prompt_user_for_all_settings: Callable[[dict], dict] = None,
+        prompt_user_for_all_settings: Callable[["Settings"], "Settings"] = None,
         default_factories: Dict[Any, Callable[[], Any]] = None,
         default_settings: Dict[Any, Any] = None,
-        dict_: dict = None,
-        **kwargs: Any,
+        data: dict = None,
+        prevent_new_settings: bool = True,
     ) -> None:
         """Initializes the settings.
 
@@ -27,49 +27,56 @@ class Settings(DefaultsDict):
         settings_file_path : str
             The absolute path to the settings file. Can be either a JSON or a
             YAML file.
-        prompt_user_for_all_settings : Callable[[dict], dict], None
+        prompt_user_for_all_settings : Callable[[Settings], Settings], None
             A function that prompts the user to enter settings and returns
-            them. The argument is the current settings as a standard Python
-            dictionary.
+            them. The argument is the current settings.
         default_factories : Dict[Any, Callable[[], Any]], None
             The dictionary of functions to call if keys are missing. Each of
             these functions must return the value for the given key (not the
             setting dictionary item).
         default_settings : Dict[Any, Any], None
             The dictionary of default settings that do NOT initialize the
-            dictionary, but instead are used by the reset method if and when a
-            setting should be reset to its default. All items this class is
-            initialized with are also saved in the default_settings dictionary,
-            so default_settings is only helpful if a default setting should be
-            saved for a key that is in default_factories. If a default setting
+            dictionary, but instead are used by a reset method if and when a
+            setting should be reset to its default. The data this class is
+            initialized with is also saved in the default_settings dictionary,
+            so default_settings is usually only used when either the ``reset``
+            method or the ``reset_all`` method is called. If a default setting
             and a default factory but not a starting item are provided for a
             key, the default factory is called.
-        dict_ : dict, None
+        data : dict, None
             The dictionary to initialize with. These items are saved in both
-            the default_settings and the data dictionary.
-        kwargs : Any
-            The keyword arguments to initialize the dictionary with. These
-            items are saved in both the default_settings and the data
-            dictionary.
+            the default settings and in the data attribute without overwriting
+            any existing default settings.
+        prevent_new_settings : bool
+            Whether or not to prevent new settings from being added to the
+            settings dictionary after this class' initialization.
         """
         self.settings_file_path = settings_file_path
         self.prompt_user_for_all_settings = prompt_user_for_all_settings
-        super().__init__(default_factories, dict_, **kwargs)
-        if default_settings is None:
-            default_settings = {}
-        self.default_settings = default_settings
-        for key, item in self.data.items():
-            self.default_settings[key] = item
+        self.prevent_new_settings = prevent_new_settings
+        self.data = data or {}
+        self.default_factories = default_factories or {}
+        self.default_settings = default_settings or {}
+        for key, value in self.data.items():
+            if key not in self.default_settings:
+                self.default_settings[key] = value
 
-    def update(self, dict_: Any = None, **kwargs: Any) -> None:
-        """Updates the settings dictionary with new items."""
-        if dict_ is not None:
-            self.data.update(dict_)
-        self.data.update(kwargs)
+    def __setitem__(self, key: Any, item: Any) -> None:
+        if self.prevent_new_settings and key not in self.data:
+            raise KeyError(f'"{key}" is not a valid setting. You can set '
+            "prevent_new_settings to False in the Settings constructor call "
+            "to allow new settings to be created after initialization.")
+        super().__setitem__(key, item)
 
-    def empty(self) -> None:
-        """Empties the settings dictionary."""
-        self.data.clear()
+    def update(self, data: dict) -> None:
+        """Updates the settings with the given dictionary.
+        
+        This update method cannot receive keyword arguments like the normal
+        dict update method can because the normal update method uses
+        ``self[key] = other[key]``, which can raise KeyError from this class's
+        ``__setitem__`` method at times when it shouldn't.
+        """
+        self.data.update(data)
 
     def reset(self, key: Any) -> None:
         """Resets a setting to its default value.
@@ -104,10 +111,11 @@ class Settings(DefaultsDict):
     ) -> None:
         """Loads the user's settings from a file.
 
-        The settings are retrieved from settings.json if the file exists and is
-        not empty. Otherwise, they are retrieved directly from the user via a
-        settings menu or from default settings in the code depending on the
-        chosen fallback option.
+        The settings are retrieved from the settings file if the file exists
+        and is not empty. Otherwise, they are retrieved directly from the user
+        via a settings menu or from default settings in the code depending on
+        the chosen fallback option. Any settings in the settings file whose
+        keys are not in any of the dictionaries in Settings are ignored.
 
         Parameters
         ----------
@@ -120,7 +128,11 @@ class Settings(DefaultsDict):
             are used.
         overwrite_existing_settings : bool
             Whether to overwrite existing settings with the settings from the
-            settings file.
+            settings file. This option is ignored if a fallback option is used;
+            using default settings never overwrites existing settings (only
+            adding new ones that don't yet exist), and prompting the user to
+            enter settings always overwrites existing settings (without
+            deleting any that are not overwritten).
 
         Raises
         ------
@@ -135,12 +147,19 @@ class Settings(DefaultsDict):
                     loaded_settings = yaml.load(file, Loader=yaml.FullLoader)
             if not loaded_settings:
                 raise FileNotFoundError
-            if overwrite_existing_settings:
-                self.data.update(loaded_settings)
-            else:
-                for key, value in loaded_settings.items():
-                    if key not in self.data:
-                        self.data[key] = value
+            for key, value in loaded_settings.items():
+                if (
+                    key in self.data
+                    and overwrite_existing_settings
+                    or (
+                        key not in self.data
+                        and (
+                            key in self.default_settings
+                            or key in self.default_factories
+                        )
+                    )
+                ):
+                    self.data[key] = value
         except (FileNotFoundError, json.JSONDecodeError, yaml.YAMLError):
             print("Unable to load the settings.")
             if fallback_option == "default settings":
@@ -154,7 +173,7 @@ class Settings(DefaultsDict):
                         "A function for prompting the user for settings was "
                         "not given upon class initialization."
                     )
-                self.data.update(self.prompt_user_for_all_settings(self.data))
+                self = self.prompt_user_for_all_settings(self)
             else:
                 raise ValueError(
                     "fallback_option must be either 'default settings' or "
